@@ -6,7 +6,7 @@ use Carp;
 
 #use Data::Dump qw( dump );
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 __PACKAGE__->mk_ro_accessors(
     qw(
@@ -97,4 +97,4 @@ same terms as Perl itself.
 
 =head1 SEE ALSO
 
-Search::Tools::QUery
+Search::Tools::Query
